bit_decomp

Function bit_decomp 

pub fn bit_decomp<S: PrimeField>(s: S, nbits: u32) -> Vec<Choice>
Convert the low nbits bits of the given Scalar to a vector of Choice. The first element of the vector is the low bit. This version runs in constant time.