compute_bitrep

Function compute_bitrep 

pub fn compute_bitrep<S: PrimeField>(x: S, bitrep_scalars: &[S]) -> Vec<Choice>
Given a vector of Scalars as output by bitrep_scalars_vartime and a private Scalar x, output a vector of Choice (of the same length as the given bitrep_scalars vector) such that x is the sum of the chosen elements of bitrep_scalars. This function should be constant time in the value of x. If x is not less than the upper used by bitrep_scalars_vartime to generate bitrep_scalars, then x will not (and indeed cannot) equal the sum of the chosen elements of bitrep_scalars.